Improve this Doc View Source
Deprecated:

In an effort to keep synchronized with router changes in Angular 2, this implementation of the Component Router (ngComponentRouter module) has been deprecated and will not receive further updates. We are investigating backporting the Angular 2 Router to Angular 1, but alternatively, use the `ngRoute` module or community developed projects (e.g. ui-router).

A `ComponentInstruction` represents the route state for a single component. An `Instruction` is composed of a tree of these `ComponentInstruction`s.

`ComponentInstructions` is a public API. Instances of `ComponentInstruction` are passed to route lifecycle hooks, like `$routerCanActivate`.

You should not modify this object. It should be treated as immutable.